import _abf
import exception
class AbfNotSupported(exception.Exception):
    pass

    
class Abf(object):
    """
    reads an axon abf file
    supports versions upto and including 2.0 (pClamp9 and pClamp10)

    all the meta data is stored in self.header dictionary
    some is copied to show the
    num_channels
    channel_names

    data access is via self.arr which is a numpy array of the form
    arr[
    
    """
    abf_modes = {
        1: 'VARLENEVENTS',
        2: 'FIXLENEVENTS',        #(ABF_FIXLENEVENTS == ABF_LOSSFREEOSC)
        3: 'LOSSFREEOSC',
        3: 'GAPFREEFILE',
        4: 'HIGHSPEEDOSC',
        5: 'WAVEFORMFILE',
        }

    def __init__(self, file_name):
        self.file_name = file_name
        self.header = _abf.get_header_info(file_name)

        if self.header['OperationMode'] == 5:
            self.description = "axon abf file recorded in episodic mode (WAVEFORMFILE mode)"
            self.header, self.arr = _abf.read_episodic_file(file_name)
            self.num_channels = self.header['ADCNumChannels']
            self.channel_names = self.header['ADCChannelName']
            self.sample_interval_us = self.header['ADCSequenceInterval']
        else:
            
            raise AbfNotSupported("Only support episodic abf files.  This type, %s, is not yet supported" % self.abf_modes[self.header['OperationMode']])
        
    def __getitem__(self,key):
        # this is prbably a silly interface-quite inefficient
        return self.arr[key]

    def __repr__(self):
        return "Abf('%s')" % self.file_name

    def __unicode__(self):
        return "Abf('%s') %s" % (self.file_name, self.modename)

    #def get_waveform(self):
        


def readabf(file_name):
    """reads an axon abf file
    supports versions upto and including 2.0 (pClamp9 and pClamp10)
    returns the data in the form of an Abf() class instance
    """
    return Abf(file_name)
